@@ -106,6 +106,20 @@ class stack(SeriesProp):
         self._add_fns(fn)
 
 
+class area(SeriesProp):
+    def __init__(self, smooth=True, lineWidth=0, showSymbol=False, opacity=0.8) -> None:
+        super().__init__()
+
+        def fn(series_obj):
+            series_obj["smooth"] = smooth
+            series_obj["lineStyle.width"] = lineWidth
+            series_obj["showSymbol"] = showSymbol
+            series_obj["areaStyle.opacity"] = opacity
+            return series_obj
+
+        self._add_fns(fn)
+
+
 class label(SeriesProp):
     def __init__(self, formatter=r"{c}") -> None:
         """
